==> python-pygame-1.9.3-1-src.tar.xz: pygame-1.9.3/src/doc/pygame_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in src/ *.doc . */
#define DOC_PYGAME "the top level pygame package"

#define DOC_PYGAMEINIT "init() -> (numpass, numfail)\ninitialize all imported pygame modules"

#define DOC_PYGAMEQUIT "quit() -> None\nuninitialize all pygame modules"

#define DOC_PYGAMEERROR "raise pygame.error(message)\nstandard pygame exception"

#define DOC_PYGAMEGETERROR "get_error() -> errorstr\nget the current error message"

#define DOC_PYGAMESETERROR "set_error(error_msg) -> None\nset the current error message"

#define DOC_PYGAMEGETSDLVERSION "get_sdl_version() -> major, minor, patch\nget the version number of SDL"

#define DOC_PYGAMEGETSDLBYTEORDER "get_sdl_byteorder() -> int\nget the byte order of SDL"

#define DOC_PYGAMEREGISTERQUIT "register_quit(callable) -> None\nregister a function to be called when pygame quits"

#define DOC_PYGAMEENCODESTRING "encode_string([obj [, encoding [, errors [, etype]]]]) -> bytes or None\nEncode a unicode or bytes object"

#define DOC_PYGAMEENCODEFILEPATH "encode_file_path([obj [, etype]]) -> bytes or None\nEncode a unicode or bytes object as a file system path"

#define DOC_PYGAMEVERSION "small module containing version information"

#define DOC_PYGAMEVERSIONVER "ver = '1.2'\nversion number as a string"

#define DOC_PYGAMEVERSIONVERNUM "vernum = (1, 5, 3)\ntupled integers of the version"

#define DOC_PYGAMEVERSIONREV "rev = 'a6f89747b551+'\nrepository revision of the build"



/* Docs in a comment... slightly easier to read. */

/*

pygame
the top level pygame package

pygame.init
 init() -> (numpass, numfail)
initialize all imported pygame modules

pygame.quit
 quit() -> None
uninitialize all pygame modules

pygame.error
 raise pygame.error(message)
standard pygame exception

pygame.get_error
 get_error() -> errorstr
get the current error message

pygame.set_error
 set_error(error_msg) -> None
set the current error message

pygame.get_sdl_version
 get_sdl_version() -> major, minor, patch
get the version number of SDL

pygame.get_sdl_byteorder
 get_sdl_byteorder() -> int
get the byte order of SDL

pygame.register_quit
 register_quit(callable) -> None
register a function to be called when pygame quits

pygame.encode_string
 encode_string([obj [, encoding [, errors [, etype]]]]) -> bytes or None
Encode a unicode or bytes object

pygame.encode_file_path
 encode_file_path([obj [, etype]]) -> bytes or None
Encode a unicode or bytes object as a file system path

pygame.version
small module containing version information

pygame.version.ver
 ver = '1.2'
version number as a string

pygame.version.vernum
 vernum = (1, 5, 3)
tupled integers of the version

pygame.version.rev
 rev = 'a6f89747b551+'
repository revision of the build

*/

==> python-pygame-1.9.4-1-src.tar.xz: pygame-1.9.4/src/doc/pygame_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in src/ *.doc . */
#define DOC_PYGAME "the top level pygame package"

#define DOC_PYGAMEINIT "init() -> (numpass, numfail)\ninitialize all imported pygame modules"

#define DOC_PYGAMEQUIT "quit() -> None\nuninitialize all pygame modules"

#define DOC_PYGAMEERROR "raise pygame.error(message)\nstandard pygame exception"

#define DOC_PYGAMEGETERROR "get_error() -> errorstr\nget the current error message"

#define DOC_PYGAMESETERROR "set_error(error_msg) -> None\nset the current error message"

#define DOC_PYGAMEGETSDLVERSION "get_sdl_version() -> major, minor, patch\nget the version number of SDL"

#define DOC_PYGAMEGETSDLBYTEORDER "get_sdl_byteorder() -> int\nget the byte order of SDL"

#define DOC_PYGAMEREGISTERQUIT "register_quit(callable) -> None\nregister a function to be called when pygame quits"

#define DOC_PYGAMEENCODESTRING "encode_string([obj [, encoding [, errors [, etype]]]]) -> bytes or None\nEncode a Unicode or bytes object"

#define DOC_PYGAMEENCODEFILEPATH "encode_file_path([obj [, etype]]) -> bytes or None\nEncode a Unicode or bytes object as a file system path"

#define DOC_PYGAMEVERSION "small module containing version information"

#define DOC_PYGAMEVERSIONVER "ver = '1.2'\nversion number as a string"

#define DOC_PYGAMEVERSIONVERNUM "vernum = (1, 5, 3)\ntupled integers of the version"

#define DOC_PYGAMEVERSIONREV "rev = 'a6f89747b551+'\nrepository revision of the build"



/* Docs in a comment... slightly easier to read. */

/*

pygame
the top level pygame package

pygame.init
 init() -> (numpass, numfail)
initialize all imported pygame modules

pygame.quit
 quit() -> None
uninitialize all pygame modules

pygame.error
 raise pygame.error(message)
standard pygame exception

pygame.get_error
 get_error() -> errorstr
get the current error message

pygame.set_error
 set_error(error_msg) -> None
set the current error message

pygame.get_sdl_version
 get_sdl_version() -> major, minor, patch
get the version number of SDL

pygame.get_sdl_byteorder
 get_sdl_byteorder() -> int
get the byte order of SDL

pygame.register_quit
 register_quit(callable) -> None
register a function to be called when pygame quits

pygame.encode_string
 encode_string([obj [, encoding [, errors [, etype]]]]) -> bytes or None
Encode a Unicode or bytes object

pygame.encode_file_path
 encode_file_path([obj [, etype]]) -> bytes or None
Encode a Unicode or bytes object as a file system path

pygame.version
small module containing version information

pygame.version.ver
 ver = '1.2'
version number as a string

pygame.version.vernum
 vernum = (1, 5, 3)
tupled integers of the version

pygame.version.rev
 rev = 'a6f89747b551+'
repository revision of the build

*/
